/*
 * cam.h
 *
 */

#ifndef CAM_H
#define CAM_H

#ifdef __cplusplus
extern "C" {
#endif

struct cam {
    int fd;                 /* V4L device file descriptor */
    unsigned min_w, min_h;  /* Minimum frame size */
    unsigned max_w, max_h;  /* Maximum frame size */
    unsigned x, y, w, h;    /* Current capture window origin and size */
    unsigned memsize;       /* Size of mapped device memory */
    unsigned char *mem;     /* Pointer to mapped device memory */
    unsigned nbufs;         /* Number of buffers */
    unsigned char **bufs;   /* Array of pointers to individual buffers */
};

extern struct cam *cam_open(const char *dev_name);
extern void cam_close(struct cam *c);

extern int cam_set_size(struct cam *c, unsigned w, unsigned h);
extern int cam_set_window(struct cam *c, unsigned x, unsigned y, unsigned w, unsigned h);

extern int cam_read_frame(struct cam *c, unsigned char *buf);

extern int cam_map_buffers(struct cam *c);
extern void cam_unmap_buffers(struct cam *c);

extern int cam_capture_request(struct cam *c, unsigned buf_nr);
extern int cam_capture_wait(struct cam *c, unsigned buf_nr);

extern int cam_capture_ready(struct cam *c);

#ifdef __cplusplus
}
#endif

#endif /* CAM_H */
