/*
 * dt.c
 *
 */

#include <stdlib.h>
#include <stdio.h>
#include <ctype.h>

#include "savepgm.h"
#include "cam.h"
#include "dead.h"

static void findDeadPixels(unsigned char *buf, unsigned w, unsigned h, int tol)
{
    int avg = bufAverage(buf, w*h);
    unsigned idx = 0;
    int n = 0;
    int minv, maxv;

    minv = avg - tol;
    if (minv < 0)
        minv = 0;
    maxv = avg + tol;
    if (maxv > 255)
        maxv = 255;

    printf("%s: avg=%d, minv=%d, maxv=%d\n", __func__, avg, minv, maxv);

    while (bufFindDeviant(buf, w*h, &idx, minv, maxv)) {
        printf("%s: dead pixel at (%d,%d), val=%d\n", __func__, idx%w, idx/w, buf[idx]);
        idx++;
        n++;
    }

    printf("%s: total %d dead pixels found\n", __func__, n);
}

#define BUFSZ   (1280*1024)

static unsigned char buf[BUFSZ];

int main(void)
{
    struct cam *c;
    char ch;

    c = cam_open("/dev/video");
    if (!c)
        exit(1);

    do {
        printf("[C] Capture   [S] Save   [D] Find Dead Pixels   [Q] Quit\n");

        ch = toupper(getchar());
        getchar();

        switch (ch) {
            case 'C':
            {
                if (cam_read_frame(c, buf))
                    exit(1);
                break;
            }

            case 'S':
            {
                save_pgm("dt.pgm", buf, c->w, c->h);
                break;
            }

            case 'D':
            {
                int tol;

                printf("tol=");
                fflush(stdout);
                scanf("%d", &tol);
                findDeadPixels(buf, c->w, c->h, tol);
                break;
            }
        }
    } while (ch != 'Q');

    cam_close(c);
    return 0;
}
