/*
 * sdlmmap.c
 *
 */

#include <stdlib.h>
#include <stdio.h>
#include <sys/time.h>

#include "tvsub.h"
#include "sdlui.h"
#include "cam.h"

int main(int argc, char *argv[])
{
    struct cam *c;
    unsigned w, h;
    unsigned frame_nr;
    struct timeval t1, t2, et;
    unsigned buf_nr;

    if (argc != 3) {
        fprintf(stderr, "usage: %s WIDTH HEIGHT\n", argv[0]);
        return 1;
    }

    c = cam_open("/dev/video");
    if (!c)
        exit(1);

    if (cam_map_buffers(c))
        exit(1);

    w = atoi(argv[1]);
    h = atoi(argv[2]);
    if (cam_set_window(c, (c->max_w - w) / 2, (c->max_h - h) / 2, w, h) < 0)
        exit(1);

    sdlUIInit(c->w, c->h, c);

    for (buf_nr = 0; buf_nr < c->nbufs; buf_nr++) {
        if (cam_capture_request(c, buf_nr))
            exit(1);
    }

    frame_nr = 0;
    buf_nr = 0;

    while (!sdlUIEvents()) {
        if (gettimeofday(&t1, NULL)) {
            perror("gettimeofday");
            exit(1);
        }

        /* Block until frame ready.
         */
        if (cam_capture_wait(c, buf_nr))
            printf("BAD FRAME\n");

        /*
         * Process this frame
         */

        sdlUIBlit(c->bufs[buf_nr]);

        /* Finished with this frame, queue it again and advance to next one.
         */
        if (cam_capture_request(c, buf_nr))
            exit(1);
        buf_nr = (buf_nr + 1) % c->nbufs;

        if (gettimeofday(&t2, NULL)) {
            perror("gettimeofday");
            exit(1);
        }

        if (timeval_subtract(&et, &t2, &t1)) {
            fprintf(stderr, "this should never happen\n");
            exit(1);
        }
        secPerFrame = et.tv_sec + et.tv_usec / 1000000.0;
    }

    cam_close(c);
    return 0;
}
