/*
 * sdlread.c
 *
 */

#include <stdlib.h>
#include <stdio.h>
#include <sys/time.h>

#include "tvsub.h"
#include "sdlui.h"
#include "cam.h"

#define BUFSZ   (1280*1024)

static unsigned char buf[BUFSZ];

int main(int argc, char *argv[])
{
    struct cam *c;
    unsigned w, h;
    unsigned frame_nr;
    struct timeval t1, t2, et;

    if (argc != 3) {
        fprintf(stderr, "usage: %s WIDTH HEIGHT\n", argv[0]);
        return 1;
    }

    c = cam_open("/dev/video");
    if (!c)
        exit(1);

    w = atoi(argv[1]);
    h = atoi(argv[2]);
    if (cam_set_window(c, (c->max_w - w) / 2, (c->max_h - h) / 2, w, h) < 0)
        exit(1);

    sdlUIInit(c->w, c->h, c);

    frame_nr = 0;

    while (!sdlUIEvents()) {
        if (gettimeofday(&t1, NULL)) {
            perror("gettimeofday");
            exit(1);
        }

        /* Block until frame ready.
         */
        if (cam_read_frame(c, buf))
            printf("BAD FRAME\n");

        /*
         * Process this frame
         */

        sdlUIBlit(buf);

        if (gettimeofday(&t2, NULL)) {
            perror("gettimeofday");
            exit(1);
        }

        if (timeval_subtract(&et, &t2, &t1)) {
            fprintf(stderr, "this should never happen\n");
            exit(1);
        }
        secPerFrame = et.tv_sec + et.tv_usec / 1000000.0;
    }

    cam_close(c);
    return 0;
}
