/*
 * sicam.c
 *
 */

#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <sys/ioctl.h>
#include <sys/time.h>

#include "siusb.h"
#include "cam.h"
#include "sicam.h"

unsigned sicam_get_clock(struct cam *c)
{
    unsigned v;

    if (ioctl(c->fd, SIUSB_IOC_GET_CLOCK, &v) < 0)
        fprintf(stderr, "%s: ioctl(): %s\n", __func__, strerror(errno));
    return v;
}

int sicam_set_clock(struct cam *c, unsigned v)
{
    if (ioctl(c->fd, SIUSB_IOC_SET_CLOCK, &v) < 0) {
        fprintf(stderr, "%s: ioctl(v=0x%08X): %s\n", __func__, v, strerror(errno));
        return -1;
    }
    return 0;
}

unsigned sicam_get_shutter_mode(struct cam *c)
{
    unsigned v;

    if (ioctl(c->fd, SIUSB_IOC_GET_SHUTTER_MODE, &v) < 0)
        fprintf(stderr, "%s: ioctl(): %s\n", __func__, strerror(errno));
    return v;
}

int sicam_set_shutter_mode(struct cam *c, unsigned v)
{
    if (ioctl(c->fd, SIUSB_IOC_SET_SHUTTER_MODE, &v) < 0) {
        fprintf(stderr, "%s: ioctl(v=0x%04X): %s\n", __func__, v, strerror(errno));
        return -1;
    }
    return 0;
}

unsigned sicam_get_exposure(struct cam *c)
{
    unsigned v;

    if (ioctl(c->fd, SIUSB_IOC_GET_EXPOSURE, &v) < 0)
        fprintf(stderr, "%s: ioctl(): %s\n", __func__, strerror(errno));
    return v;
}

int sicam_set_exposure(struct cam *c, unsigned v)
{
    if (ioctl(c->fd, SIUSB_IOC_SET_EXPOSURE, &v) < 0) {
        fprintf(stderr, "%s: ioctl(v=%u): %s\n", __func__, v, strerror(errno));
        return -1;
    }
    return 0;
}

unsigned sicam_get_gain(struct cam *c)
{
    unsigned v;

    if (ioctl(c->fd, SIUSB_IOC_GET_GAIN, &v) < 0)
        fprintf(stderr, "%s: ioctl(): %s\n", __func__, strerror(errno));
    return v;
}

int sicam_set_gain(struct cam *c, unsigned v)
{
    if (ioctl(c->fd, SIUSB_IOC_SET_GAIN, &v) < 0) {
        fprintf(stderr, "%s: ioctl(v=0x%02X): %s\n", __func__, v, strerror(errno));
        return -1;
    }
    return 0;
}

unsigned sicam_get_black_level(struct cam *c)
{
    unsigned v;

    if (ioctl(c->fd, SIUSB_IOC_GET_BLACK_LEVEL, &v) < 0)
        fprintf(stderr, "%s: ioctl(): %s\n", __func__, strerror(errno));
    return v;
}

int sicam_set_black_level(struct cam *c, unsigned v)
{
    if (ioctl(c->fd, SIUSB_IOC_SET_BLACK_LEVEL, &v) < 0) {
        fprintf(stderr, "%s: ioctl(v=%u): %s\n", __func__, v, strerror(errno));
        return -1;
    }
    return 0;
}

unsigned sicam_get_black_balance(struct cam *c)
{
    unsigned v;

    if (ioctl(c->fd, SIUSB_IOC_GET_BLACK_BALANCE, &v) < 0)
        fprintf(stderr, "%s: ioctl(): %s\n", __func__, strerror(errno));
    return v;
}

int sicam_set_black_balance(struct cam *c, unsigned v)
{
    if (ioctl(c->fd, SIUSB_IOC_SET_BLACK_BALANCE, &v) < 0) {
        fprintf(stderr, "%s: ioctl(v=%u): %s\n", __func__, v, strerror(errno));
        return -1;
    }
    return 0;
}

unsigned sicam_get_trig_mode(struct cam *c)
{
    unsigned v;

    if (ioctl(c->fd, SIUSB_IOC_GET_TRIG_MODE, &v) < 0)
        fprintf(stderr, "%s: ioctl(): %s\n", __func__, strerror(errno));
    return v;
}

void sicam_set_trig_mode(struct cam *c, unsigned v)
{
    if (ioctl(c->fd, SIUSB_IOC_SET_TRIG_MODE, &v) < 0)
        fprintf(stderr, "%s: ioctl(v=%u): %s\n", __func__, v, strerror(errno));
}
