/*
 * siusb.h
 *
 * SI-1280F USB Camera Driver
 *
 * Copyright (C) 2003-2004 Nikka Research Deutschland GmbH
 */

#ifndef SIUSB_H
#define SIUSB_H

#include <linux/videodev.h>

/* Clock
 */
#define SIUSB_CLK_20MHZ         (0x30|(0x68<<8)|(0x86<<16))
#define SIUSB_CLK_25MHZ         (0x30|(0xB6<<8)|(0x89<<16))
#define SIUSB_CLK_30MHZ         (0x37|(0xCB<<8)|(0x8F<<16))
#define SIUSB_CLK_35MHZ         (0x35|(0xD4<<8)|(0x0B<<16))
#define SIUSB_CLK_40MHZ         (0x30|(0x68<<8)|(0x82<<16))
#define SIUSB_CLK_45MHZ         (0x35|(0xE7<<8)|(0x09<<16))
#define SIUSB_CLK_50MHZ         (0x34|(0xB6<<8)|(0x89<<16))
#define SIUSB_CLK_55MHZ         (0x34|(0xB6<<8)|(0x88<<16))
#define SIUSB_CLK_60MHZ         (0x36|(0xCB<<8)|(0x8F<<16))

/* Shutter mode
 */
#define SIUSB_SH_ROLLING        0x005
#define SIUSB_SH_ROLLING_DS1    0x105
#define SIUSB_SH_ROLLING_DS2    0x205
#define SIUSB_SH_ROLLING_DS3    0x305
#define SIUSB_SH_TRIG_TB1       0x004
#define SIUSB_SH_TRIG_TB2       0x044
#define SIUSB_SH_TRIG_TB3       0x084
#define SIUSB_SH_TRIG_TB4       0x0C4

/* System clocks per exposure clock
 */
#define SIUSB_EXPCLK_TB1        32
#define SIUSB_EXPCLK_TB2        64
#define SIUSB_EXPCLK_TB3        128
#define SIUSB_EXPCLK_TB4        256

/* Exposure
 */
#define SIUSB_EXPOSURE_MAX      4095

/* Gain
 */
#define SIUSB_GAIN_1_41         0x40
#define SIUSB_GAIN_1_62         0x41
#define SIUSB_GAIN_1_88         0x42
#define SIUSB_GAIN_2_17         0x43
#define SIUSB_GAIN_2_52         0x44
#define SIUSB_GAIN_2_92         0x45
#define SIUSB_GAIN_3_38         0x46
#define SIUSB_GAIN_3_90         0x47
#define SIUSB_GAIN_4_50         0x48
#define SIUSB_GAIN_5_17         0x49
#define SIUSB_GAIN_5_93         0x4A
#define SIUSB_GAIN_6_76         0x4B
#define SIUSB_GAIN_7_86         0x4C
#define SIUSB_GAIN_8_64         0x4D
#define SIUSB_GAIN_9_61         0x4E
#define SIUSB_GAIN_10_69        0x4F
#define SIUSB_GAIN_1_00         0x50
#define SIUSB_GAIN_MIN          SIUSB_GAIN_1_41
#define SIUSB_GAIN_MAX          SIUSB_GAIN_10_69
#define SIUSB_GAIN_UNITY        SIUSB_GAIN_1_00

/* Black level
 */
#define SIUSB_BLACK_LEVEL_MAX   127

/* Black balance
 */
#define SIUSB_BLACK_BALANCE_MAX 127

/* Trigger mode
 */
#define SIUSB_TRIG_MODE_INT     0
#define SIUSB_TRIG_MODE_EXT     1

/* ioctls
 */

#define SIUSB_IOC_GET_CLOCK         _IOR('v', BASE_VIDIOCPRIVATE+ 0, unsigned)
#define SIUSB_IOC_SET_CLOCK         _IOW('v', BASE_VIDIOCPRIVATE+ 1, unsigned)

#define SIUSB_IOC_GET_SHUTTER_MODE  _IOR('v', BASE_VIDIOCPRIVATE+ 2, unsigned)
#define SIUSB_IOC_SET_SHUTTER_MODE  _IOW('v', BASE_VIDIOCPRIVATE+ 3, unsigned)

#define SIUSB_IOC_GET_EXPOSURE      _IOR('v', BASE_VIDIOCPRIVATE+ 4, unsigned)
#define SIUSB_IOC_SET_EXPOSURE      _IOW('v', BASE_VIDIOCPRIVATE+ 5, unsigned)

#define SIUSB_IOC_GET_GAIN          _IOR('v', BASE_VIDIOCPRIVATE+ 6, unsigned)
#define SIUSB_IOC_SET_GAIN          _IOW('v', BASE_VIDIOCPRIVATE+ 7, unsigned)

#define SIUSB_IOC_GET_BLACK_LEVEL   _IOR('v', BASE_VIDIOCPRIVATE+ 8, unsigned)
#define SIUSB_IOC_SET_BLACK_LEVEL   _IOW('v', BASE_VIDIOCPRIVATE+ 9, unsigned)

#define SIUSB_IOC_GET_BLACK_BALANCE _IOR('v', BASE_VIDIOCPRIVATE+10, unsigned)
#define SIUSB_IOC_SET_BLACK_BALANCE _IOW('v', BASE_VIDIOCPRIVATE+11, unsigned)

#define SIUSB_IOC_GET_TRIG_MODE     _IOR('v', BASE_VIDIOCPRIVATE+12, unsigned)
#define SIUSB_IOC_SET_TRIG_MODE     _IOW('v', BASE_VIDIOCPRIVATE+13, unsigned)

#endif /* SIUSB_H */
