/*
 * tread.c
 *
 */

#include <stdlib.h>
#include <stdio.h>
#include <sys/time.h>

#include "kbhit.h"
#include "tvsub.h"
#include "cam.h"

#define BUFSZ   (1280*1024)

static unsigned char buf[BUFSZ];

int main(int argc, char *argv[])
{
    struct cam *c;
    unsigned w, h;
    unsigned frame_nr;
    struct timeval t1, t2, et;
    double total_sec;

    if (argc != 3) {
        fprintf(stderr, "usage: %s WIDTH HEIGHT\n", argv[0]);
        return 1;
    }

    c = cam_open("/dev/video");
    if (!c)
        exit(1);

    w = atoi(argv[1]);
    h = atoi(argv[2]);
    if (cam_set_window(c, (c->max_w - w) / 2, (c->max_h - h) / 2, w, h) < 0)
        exit(1);

    frame_nr = 0;
    total_sec = 0.0;

    while (!kbhit()) {
        if (gettimeofday(&t1, NULL)) {
            perror("gettimeofday");
            exit(1);
        }

        /* Block until frame ready.
         */
        if (cam_read_frame(c, buf))
            exit(1);

        /*
         * Process this frame
         */

        if (gettimeofday(&t2, NULL)) {
            perror("gettimeofday");
            exit(1);
        }

        if (timeval_subtract(&et, &t2, &t1)) {
            fprintf(stderr, "this should never happen\n");
            exit(1);
        }
        if (et.tv_sec)
            printf("tv_sec != 0\n");
        total_sec += et.tv_usec / 1000000.0;

        printf("frame %u: ready: %.2f msec\n",
               frame_nr++, et.tv_usec / 1000.0);
    }

    cam_close(c);

    printf("%.2f fps\n", frame_nr / total_sec);
    return 0;
}
